.. include:: ../../README.rst



Feedback
--------

If you encounter any errors or problems with **intake-esm**,
please open an issue at the GitHub `main repository <http://github.com/NCAR/intake-esm>`_.


.. toctree::
   :maxdepth: 2
   :caption: Documentation Contents


   installation
   notebooks/tutorial.ipynb
   faq
   cmip_ap
   api
   contributing
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
